@@ -63,13 +63,14 @@ class RenderersDialog : DialogFragment(), RendererDelegate.RendererListener, Pla
     override fun onCreateDialog(savedInstanceState: Bundle?): Dialog {
         val inflater = LayoutInflater.from(context)
         mBinding = DialogRenderersBinding.inflate(inflater, null)
-        val dialog = Dialog(context, R.style.ThemeOverlay_AppCompat_Dialog)
+        val dialog = Dialog(context)
         dialog.requestWindowFeature(Window.FEATURE_NO_TITLE)
         dialog.setContentView(mBinding.root)
         return dialog
     }
 
     override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
+        setStyle(DialogFragment.STYLE_NO_FRAME, 0)
         mBinding = DialogRenderersBinding.inflate(inflater, container, false)
         return mBinding.root
     }
@@ -127,12 +128,12 @@ class RenderersDialog : DialogFragment(), RendererDelegate.RendererListener, Pla
 
     inner class RendererClickhandler {
         fun connect(item: RendererItem?) {
-            RendererDelegate.selectRenderer(item)
             mService?.setRenderer(item)
+            dismissAllowingStateLoss()
+            RendererDelegate.selectRenderer(item)
             if (item !== null) activity?.window?.findViewById<View>(R.id.audio_player_container)?.let {
                 UiTools.snacker(it, getString(R.string.casting_connected_renderer, item.displayName))
             }
-            dismiss()
         }
     }
 }
